@@ -1,9 +1,11 @@
 package App::Env::Example;
 
+# ABSTRACT: example application environment module for App::Env.
+
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 # This example uses Shell::GetEnv to illustrate how to source a shell
 # script which defines the environment for an application.  Other
@@ -14,22 +16,38 @@ use Shell::GetEnv;
 
 sub envs
 {
-    my ( $opt ) = @_;
+    #     my ( $opt ) = @_;
 
     # source the shell script and return the changed environment
     return Shell::GetEnv->new( 'tcsh',
-			       'source /usr/local/mypkg/setup.csh'
-			     )->envs;
+                               'source /usr/local/mypkg/setup.csh'
+                             )->envs;
 }
 
 1;
 
+#
+# This file is part of App-Env
+#
+# This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
+
 __END__
 
+=pod
+
 =head1 NAME
 
 App::Env::Example - example application environment module for App::Env.
 
+=head1 VERSION
+
+version 0.34
+
 =head1 DESCRIPTION
 
 Modules used by B<App::Env> to load application environments are named
@@ -40,7 +58,6 @@ or, if there is a site specific version:
 
   App::Env::<SITE>::<application>
 
-
 It is very important that the loaded environment be based upon the
 I<current> environment.  For example, if the environment is derived
 from running a shell script, make sure either that the shell script is
@@ -106,5 +123,45 @@ B<App::Env::import> via the B<AppOpts> option.
 
 =back
 
-
 See the source of this module for a simple example.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Env> or by email to
+L<bug-App-Env@rt.cpan.org|mailto:bug-App-Env@rt.cpan.org>.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 SOURCE
+
+The development version is on github at L<https://github.com/djerius/app-env>
+and may be cloned from L<git://github.com/djerius/app-env.git>
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<App::Env|App::Env>
+
+=back
+
+=head1 AUTHOR
+
+Diab Jerius <djerius@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=cut
